==> openshift-java-client-1.0.0-sources.jar: com/openshift/express/internal/client/utils/IOpenShiftJsonConstants.java <==
/******************************************************************************* 
 * Copyright (c) 2011 Red Hat, Inc. 
 * Distributed under license by Red Hat, Inc. All rights reserved. 
 * This program is made available under the terms of the 
 * Eclipse Public License v1.0 which accompanies this distribution, 
 * and is available at http://www.eclipse.org/legal/epl-v10.html 
 * 
 * Contributors: 
 * Red Hat, Inc. - initial API and implementation 
 ******************************************************************************/ 
package com.openshift.express.internal.client.utils;

/**
 * @author André Dietisheim
 */
public class IOpenShiftJsonConstants {

	public static final String PROPERTY_DEBUG = "debug";
	public static final String PROPERTY_RHLOGIN = "rhlogin";

	public static final String PROPERTY_CART_TYPE = "cart_type";

	public static final String PROPERTY_MESSAGES = "messages";
	public static final String PROPERTY_RESULT = "result";
	public static final String PROPERTY_EXIT_CODE = "exit_code";
	public static final String PROPERTY_DATA = "data";
	public static final String PROPERTY_APP_NAME = "app_name";
	public static final String PROPERTY_ACTION = "action";
	public static final String PROPERTY_CARTRIDGE = "cartridge";
	public static final String PROPERTY_CARTS = "carts";
	public static final String PROPERTY_NAMESPACE = "namespace";
	public static final String PROPERTY_ALTER = "alter";
	public static final String PROPERTY_SSH = "ssh";
	public static final String PROPERTY_UUID = "uuid";
	public static final String PROPERTY_USER_INFO = "user_info";
	public static final String PROPERTY_APP_INFO = "app_info";
	public static final String PROPERTY_RHC_DOMAIN = "rhc_domain";
	public static final String PROPERTY_EMBEDDED = "embedded";
	public static final String PROPERTY_FRAMEWORK = "framework";
	public static final String PROPERTY_CREATION_TIME = "creation_time";
	public static final String PROPERTY_SSH_KEY = "ssh_key";
	public static final String PROPERTY_INFO = "info";
	
}

==> openshift-java-client-1.0.1-20120126.200231-1-sources.jar: com/openshift/express/internal/client/utils/IOpenShiftJsonConstants.java <==
/******************************************************************************* 
 * Copyright (c) 2011 Red Hat, Inc. 
 * Distributed under license by Red Hat, Inc. All rights reserved. 
 * This program is made available under the terms of the 
 * Eclipse Public License v1.0 which accompanies this distribution, 
 * and is available at http://www.eclipse.org/legal/epl-v10.html 
 * 
 * Contributors: 
 * Red Hat, Inc. - initial API and implementation 
 ******************************************************************************/ 
package com.openshift.express.internal.client.utils;

/**
 * @author André Dietisheim
 */
public class IOpenShiftJsonConstants {

	public static final String PROPERTY_DEBUG = "debug";
	public static final String PROPERTY_RHLOGIN = "rhlogin";

	public static final String PROPERTY_CART_TYPE = "cart_type";

	public static final String PROPERTY_MESSAGES = "messages";
	public static final String PROPERTY_RESULT = "result";
	public static final String PROPERTY_EXIT_CODE = "exit_code";
	public static final String PROPERTY_DATA = "data";
	public static final String PROPERTY_APP_NAME = "app_name";
	public static final String PROPERTY_ACTION = "action";
	public static final String PROPERTY_CARTRIDGE = "cartridge";
	public static final String PROPERTY_NODE_PROFILE = "node_profile";
	public static final String PROPERTY_CARTS = "carts";
	public static final String PROPERTY_NAMESPACE = "namespace";
	public static final String PROPERTY_ALTER = "alter";
	public static final String PROPERTY_SSH = "ssh";
	public static final String PROPERTY_SSH_TYPE = "ssh_type";
	public static final String PROPERTY_TYPE = "type";
	public static final String PROPERTY_UUID = "uuid";
	public static final String PROPERTY_USER_INFO = "user_info";
	public static final String PROPERTY_APP_INFO = "app_info";
	public static final String PROPERTY_RHC_DOMAIN = "rhc_domain";
	public static final String PROPERTY_EMBEDDED = "embedded";
	public static final String PROPERTY_FRAMEWORK = "framework";
	public static final String PROPERTY_CREATION_TIME = "creation_time";
	public static final String PROPERTY_SSH_KEY = "ssh_key";
	public static final String PROPERTY_KEY_TYPE = "key_type";
	public static final String PROPERTY_INFO = "info";
	public static final String PROPERTY_HEALTH_CHECK_PATH = "health_check_path";
}
